@@ -189,8 +189,11 @@ class Pool(object):
     def introspect(self):
         ret = []
         for process in self._pool:
-            process.intro_conn.send(True)
-            ret.append(process.intro_conn.recv())
+            if process.is_alive():
+                process.intro_conn.send(True)
+                ret.append(process.intro_conn.recv())
+            else:
+                ret.append({ 'state' : 'EXITED', 'trace' : '' })
         return ret
     
     def resize(self, size):
