@@ -10,8 +10,8 @@ if __name__ == '__main__':
     for i in range(0, 8):
         res = p.apply_async(fun, args=[3])
     print '=' * 30, 'Starting traceback test', '=' * 30
-    for trace in p.get_tracebacks():
-        print trace
+    for info in p.introspect():
+        print info['trace']
         print '-' * 50
     res.get()
     print '=' * 30, 'Ending traceback test', '=' * 30
